@@ -67,6 +67,9 @@ class RKClient:
         self.insecure = insecure
         if self.insecure:
             log.warning("Disabled SSL certificate check")
+        if "https://" not in self.receiver_url and "http://receiver:8083" not in self.receiver_url and \
+                "localhost" not in self.receiver_url and "127.0.0.1" not in self.receiver_url:
+            log.warning("If you're connecting to https server without specifying https in url, expect 405 errors")
 
     def __enter__(self):
         return self
@@ -196,9 +199,9 @@ class RKClient:
         try:
             resp = urllib.request.urlopen(request, timeout=self.timeout_sec, context=self._get_ssl_context())
         except HTTPError as e:
-            return f"error: {e}", False
+            return f"error: {e} {e.read().decode()}", False
         except URLError as e:
-            return f"connection error: {e.reason}", False
+            return f"connection error: {e}", False
         else:
             return resp.read().decode(), True
 
